from distutils.core import setup
setup(
    name        =       'linpenga',
    version     =       '2.0.1',
    py_modules  =       ['linpenga'],
    author      =       'lin',
    author_email=       'hfpython@headfirstlabs.com',
    url         =       'http://www.headfirstlabs.com',
    description =       'A simple printer of nested lists',
    )
